* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';                                            
* Kill default titles on output; 
TITLE; ODS LISTING;

***********************************************************************************;
*******    MACRO PROGRAMS TO AUTOMATE CALCULATIONS FOR EXAMPLE 2-3          *******;
*******               NOTHING IN HERE NEEDS TO BE CHANGED                   *******;
***********************************************************************************;

* To use FitTest macro;
* FitFewer = Name of ODS InfoCrit table for nested model;
* FitMore  = Name of ODS InfoCrit table for comparison model;
%MACRO FitTest(FitFewer=,FitMore=);
DATA &FitFewer.; LENGTH Name $30.; SET &FitFewer.; Name="&FitFewer."; RUN;
DATA &FitMore.;  LENGTH Name $30.; SET &FitMore.;  Name="&FitMore.";  RUN;
DATA FitCompare; LENGTH Name $30.; SET &FitFewer. &FitMore.; RUN;
DATA FitCompare; SET FitCompare; DevDiff=Lag1(Neg2LogLike)-Neg2LogLike;
     DFdiff=Parms-LAG1(Parms); Pvalue=1-PROBCHI(DevDiff,DFdiff);
     DROP AICC HQIC CAIC; RUN;
TITLE9 "Likelihood Ratio Test for &FitFewer. vs. &FitMore.";
PROC PRINT NOOBS DATA=FitCompare; RUN; TITLE9;
%MEND FitTest;

* To use TotalR2 macro;
* DV =        Case-sensitive name of dependent variable;
* PredFewer = Name of OUTPM= data file of predicted outcomes for nested model;
* PredMore =  Name of OUTPM= data file of predicted outcomes for comparison model;
%MACRO TotalR2(DV=,PredFewer=,PredMore=);
PROC CORR NOPRINT NOSIMPLE DATA=&PredFewer. OUTP=CorrFewer; VAR pred &DV.; RUN;
PROC CORR NOPRINT NOSIMPLE DATA=&PredMore.  OUTP=CorrMore;  VAR pred &DV.; RUN;
DATA CorrFewer; LENGTH Name $30.; SET CorrFewer; Name="&PredFewer."; RUN;
DATA CorrMore;  LENGTH Name $30.; SET CorrMore;  Name="&PredMore.";  RUN;
DATA CorrCompare; LENGTH Name $30.; SET CorrFewer CorrMore; 
     PredCorr=Pred; TotalR2=PredCorr*PredCorr; 
     IF _NAME_="Pred" OR MISSING(_NAME_)=1 THEN DELETE; DROP Pred; RUN;
DATA CorrCompare; SET CorrCompare; TotalR2Diff=TotalR2-LAG1(TotalR2);
     KEEP Name PredCorr TotalR2 TotalR2Diff; RUN; 
TITLE9 "Total R2 (% Reduction) for &PredFewer. vs. &PredMore.";
PROC PRINT NOOBS DATA=CorrCompare; RUN; TITLE9; 
%MEND TotalR2;

* To use PseudoR2 macro;
* Ncov =     TOTAL # entries in covariance parameter estimates table;
* CovFewer = Name of ODS CovParms table for nested model;
* CovMore =  Name of ODS CovParms table for comparison model;
%MACRO PseudoR2(NCov=,CovFewer=,CovMore=);
DATA &CovFewer.; LENGTH Name $30.; SET &CovFewer.; Name="&CovFewer."; RUN;
DATA &CovMore.;  LENGTH Name $30.; SET &CovMore.;  Name="&CovMore.";  RUN;
DATA CovCompare; LENGTH Name $30.; SET &CovFewer. &CovMore.; RUN;
DATA CovCompare; SET CovCompare; 
     PseudoR2=(LAG&Ncov.(Estimate)-Estimate)/LAG&Ncov.(Estimate); RUN;
DATA CovCompare; SET CovCompare; 
     IF CovParm IN("UN(2,1)","UN(3,1)","UN(4,1)","UN(3,2)","UN(4,2)","UN(4,3)") 
     THEN DELETE; RUN;
TITLE9 "PsuedoR2 (% Reduction) for &CovFewer. vs. &CovMore.";
PROC PRINT NOOBS DATA=CovCompare; RUN; TITLE9;
%MEND PseudoR2;

******************************************************************************;
******                      EXAMPLE 2 MODELS                            ******;
******************************************************************************;

* Define global variable for file location -- CHANGE THIS TO YOUR DIRECTORY;
%LET example=C:\Dropbox\Workshop_Illinois_2018\Download\SAS;
LIBNAME example "&example.";

* Import data into work library and center predictors for analysis;
DATA work.Example23; SET example.Example23;
  * Center time for polynomial models;
    c1sess = Session - 1; LABEL c1sess = "c1sess: Session Centered at 1"; RUN;
     
* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example2_SAS_Output.txt" 
             LOG=  "&example.\Example2_SAS_Output.txt"; RUN;

TITLE1 "SAS Model 0: Saturated Means, Unstructured Variances";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = session / SOLUTION DDFM=Satterthwaite;
     REPEATED session / R RCORR TYPE=UN SUBJECT=ID;
     LSMEANS session /; 
RUN; TITLE1;

TITLE1 "SAS Model 1a: Empty Means, Random Intercept";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt =  / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=ID;
     REPEATED session / R TYPE=VC SUBJECT=ID; 
     ODS OUTPUT CovParms=CovEmpty; * CovParms saves estimates to calculate pseudo-R2; 
RUN; TITLE1;

TITLE1 "SAS Model 2a: Fixed Linear Time, Random Intercept";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=ID;
     REPEATED session / R TYPE=VC SUBJECT=ID; 
     * CovParms will be used for pseudo-R2, InfoCrit for LRT against next model;
     ODS OUTPUT CovParms=CovFixLin InfoCrit=FitFixLin; 
RUN; TITLE1; 
* Call macro to calculate pseudo R2;
%PseudoR2(NCov=2, CovFewer=CovEmpty, CovMore=CovFixLin);

TITLE1 "SAS Model 2b: Random Linear Time";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT c1sess / G GCORR V VCORR TYPE=UN SUBJECT=ID;
     REPEATED session / R TYPE=VC SUBJECT=ID; 
     * CovParms will be used for pseudo-R2, InfoCrit for LRT against next model;
     ODS OUTPUT CovParms=CovRandLin InfoCrit=FitRandLin;
RUN; TITLE1;
* Call macro to calculate LRT for nested models;
%FitTest(FitFewer=FitFixLin, FitMore=FitRandLin);

TITLE1 "SAS Model 3a: Fixed Quadratic, Random Linear Time";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess c1sess*c1sess / SOLUTION DDFM=Satterthwaite OUTPM=PredTime;
     RANDOM INTERCEPT c1sess / G GCORR V VCORR TYPE=UN SUBJECT=ID;
     REPEATED session / R TYPE=VC SUBJECT=ID; 
     * CovParms will be used for pseudo-R2, InfoCrit for LRT against next model;
     ODS OUTPUT CovParms=CovFixQuad InfoCrit=FitFixQuad; 
RUN; TITLE1;
* Call macro to calculate pseudo R2;
%PseudoR2(NCov=4, CovFewer=CovRandLin, CovMore=CovFixQuad);
* Get total R2 from fixed linear and fixed quadratic time;
PROC CORR NOSIMPLE DATA=PredTime; VAR pred; WITH nm3rt; RUN;

TITLE1 "SAS Model 3b: Random Quadratic Time";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess c1sess*c1sess / SOLUTION DDFM=Satterthwaite;
     RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR V VCORR TYPE=UN SUBJECT=ID;
     REPEATED session / R TYPE=VC SUBJECT=ID;
     ODS OUTPUT CovParms=CovTime InfoCrit=FitRandQuad; * Save for pseudo-R2, LRT; 
     * Predicting means from model for each session;
     ESTIMATE "Intercept at Session 1"  intercept 1 c1sess 0 c1sess*c1sess 0;
     ESTIMATE "Intercept at Session 2"  intercept 1 c1sess 1 c1sess*c1sess 1;
     ESTIMATE "Intercept at Session 3"  intercept 1 c1sess 2 c1sess*c1sess 4;
     ESTIMATE "Intercept at Session 4"  intercept 1 c1sess 3 c1sess*c1sess 9;
     ESTIMATE "Intercept at Session 5"  intercept 1 c1sess 4 c1sess*c1sess 16;
     ESTIMATE "Intercept at Session 6"  intercept 1 c1sess 5 c1sess*c1sess 25;
     * Predicting linear rate of change at each session (linear changes by 2*quad);
     ESTIMATE "Linear Slope at Session 1" c1sess 1 c1sess*c1sess 0;
     ESTIMATE "Linear Slope at Session 2" c1sess 1 c1sess*c1sess 2;
     ESTIMATE "Linear Slope at Session 3" c1sess 1 c1sess*c1sess 4;
     ESTIMATE "Linear Slope at Session 4" c1sess 1 c1sess*c1sess 6;
     ESTIMATE "Linear Slope at Session 5" c1sess 1 c1sess*c1sess 8;
     ESTIMATE "Linear Slope at Session 6" c1sess 1 c1sess*c1sess 10; 
RUN; TITLE1;

* Close output;
PROC PRINTTO; RUN;


******************************************************************************;
******                      EXAMPLE 3 MODELS                            ******;
******************************************************************************;

* Center level-2 predictor variables for analysis;
DATA work.Example23; SET work.Example23;
    age80  = age - 80;      * 80 = convenient value;
    reas22 = absreas - 22;  * 22 = near sample mean;     
    LABEL age80  = "age80: Age Centered (0=80)" 
          reas22 = "reas22: Abstract Reasoning Centered (0=22)"; 
    * Make education a grouping variable for purpose of demonstration only;
         IF educyrs LE 12                   THEN educgrp=1;
    ELSE IF educyrs GT 12 AND EducYrs LE 16 THEN educgrp=2;
    ELSE IF educyrs GT 16                   THEN educgrp=3;
    ELSE IF educyrs = .                     THEN educgrp=.;
    LABEL educgrp = "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)";
* Remove cases with missing predictors;
    IF NMISS(age80, reas22, educgrp)>0 THEN DELETE;
RUN;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example3_SAS_Output.txt" 
             LOG=  "&example.\Example3_SAS_Output.txt"; RUN;

TITLE1 "SAS Model 4a: Add Age as Predictor of Intercept, Linear, and Quadratic";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 
                     / SOLUTION DDFM=Satterthwaite OUTPM=work.PredAge;
     RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID;
     REPEATED session / TYPE=VC SUBJECT=ID; 
	ODS OUTPUT CovParms=CovAge; * Save for pseudo-R2;
	CONTRAST "DF=3 Wald Test for Age Effects" Age80 1, Age80*c1sess 1, Age80*c1sess*c1sess 1 / CHISQ;
     * Requesting additional effects for age;
     ESTIMATE "Age Effect at Session 1" age80 1 c1sess*age80 0 c1sess*c1sess*age80 0;
     ESTIMATE "Age Effect at Session 2" age80 1 c1sess*age80 1 c1sess*c1sess*age80 1;
     ESTIMATE "Age Effect at Session 3" age80 1 c1sess*age80 2 c1sess*c1sess*age80 4;
     ESTIMATE "Age Effect at Session 4" age80 1 c1sess*age80 3 c1sess*c1sess*age80 9;
     ESTIMATE "Age Effect at Session 5" age80 1 c1sess*age80 4 c1sess*c1sess*age80 16;
     ESTIMATE "Age Effect at Session 6" age80 1 c1sess*age80 5 c1sess*c1sess*age80 25; 
RUN; TITLE1;
* Calculate Total R2 change relative to unconditional model;
%TotalR2(DV=nm3rt, PredFewer=PredTime, PredMore=PredAge);
* Calculate PseudoR2 relative to unconditional time model;
%PseudoR2(NCov=7, CovFewer=CovTime, CovMore=CovAge);

TITLE1 "SAS Model 5a: Add Reasoning as Predictor of Intercept, Linear, and Quadratic";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
                   reas22 c1sess*reas22 c1sess*c1sess*reas22 
                        / SOLUTION DDFM=Satterthwaite OUTPM=work.PredReasQ;
    RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID; 
    REPEATED session / TYPE=VC SUBJECT=ID;
    ODS OUTPUT CovParms=CovReasQ; * Save for pseudo-R2;
    CONTRAST "DF=3 Wald Test for Reas Effects" Reas22 1, Reas22*c1sess 1, Reas22*c1sess*c1sess 1 / CHISQ;
RUN; TITLE1;
* Calculate Total R2 change relative to age model;
%TotalR2(DV=nm3rt, PredFewer=PredAge, PredMore=PredReasQ);
* Calculate PseudoR2 relative to age model;
%PseudoR2(NCov=7, CovFewer=CovAge, CovMore=CovReasQ);

TITLE1 "SAS Model 5b: Add Reasoning as Predictor of Intercept and Linear Time Slope Only";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session;
     MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
                   reas22 c1sess*reas22   
                      / SOLUTION DDFM=Satterthwaite OUTPM=work.PredReasL;
     RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID; 
     REPEATED session / TYPE=VC SUBJECT=ID;
	ODS OUTPUT CovParms=CovReasL; * Save for pseudo-R2;
	CONTRAST "DF=2 Wald Test for Reas Effects" Reas22 1, Reas22*c1sess 1 / CHISQ;
     * Requesting additional effects for reasoning instead;
     ESTIMATE "Reasoning Effect at Session 1" reas22 1 c1sess*reas22 0;
     ESTIMATE "Reasoning Effect at Session 2" reas22 1 c1sess*reas22 1;
     ESTIMATE "Reasoning Effect at Session 3" reas22 1 c1sess*reas22 2;
     ESTIMATE "Reasoning Effect at Session 4" reas22 1 c1sess*reas22 3;
     ESTIMATE "Reasoning Effect at Session 5" reas22 1 c1sess*reas22 4;
     ESTIMATE "Reasoning Effect at Session 6" reas22 1 c1sess*reas22 5;
RUN; TITLE1;
* Calculate Total R2 change relative to age model;
%TotalR2(DV=nm3rt, PredFewer=PredAge, PredMore=PredReasL);
* Calculate PseudoR2 relative to age model;
%PseudoR2(NCov=7, CovFewer=CovAge, CovMore=CovReasL);

TITLE1 "SAS Model 6a: Add Education Group As Predictor of Intercept, Linear, and Quadratic";
PROC MIXED DATA=work.Example23 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS ID session educgrp;
     MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
                   reas22 c1sess*reas22 
                   educgrp c1sess*educgrp c1sess*c1sess*educgrp 
                    / SOLUTION DDFM=Satterthwaite OUTPM=work.PredEduc;
     RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID; 
     REPEATED session / TYPE=VC SUBJECT=ID;
	ODS OUTPUT CovParms=CovEduc; * Save for pseudo-R2;
	CONTRAST "DF=6 Wald Test for Effects of Education" educgrp -1 1 0, educgrp -1 0 1, 
               c1sess*educgrp -1 1 0, c1sess*educgrp -1 0 1, 
               c1sess*c1sess*educgrp -1 1 0, c1sess*c1sess*educgrp -1 0 1 / CHISQ;
     * LSMEANS gives follow-up tests and means per group for main effect only;
     LSMEANS educgrp  / AT (c1sess) = (0) DIFF=ALL; 
     LSMEANS educgrp  / AT (c1sess) = (5) DIFF=ALL; 
     * ESTIMATE statements can also give specific effects as before;
     ESTIMATE "L vs. H Educ for Intercept Main Effect"  educgrp -1  0  1 ;
     ESTIMATE "M vs. H Educ for Intercept Main Effect"  educgrp  0 -1  1 ;
     ESTIMATE "L vs. M Educ for Intercept Main Effect"  educgrp -1  1  0 ;
     ESTIMATE "L vs. H Educ for Linear Session"  c1sess*educgrp -1  0  1 ;
     ESTIMATE "M vs. H Educ for Linear Session"  c1sess*educgrp  0 -1  1 ;
     ESTIMATE "L vs. M Educ for Linear Session"  c1sess*educgrp -1  1  0 ;
     ESTIMATE "L vs. H Educ for Quadratic Session"  c1sess*c1sess*educgrp -1  0  1 ;    
     ESTIMATE "M vs. H Educ for Quadratic Session"  c1sess*c1sess*educgrp  0 -1  1 ;
     ESTIMATE "L vs. M Educ for Quadratic Session"  c1sess*c1sess*educgrp -1  1  0 ;
RUN; TITLE1;
* Calculate Total R2 change relative to reasL model;
%TotalR2(DV=nm3rt, PredFewer=PredReasL, PredMore=PredEduc);
* Calculate PseudoR2 relative to reasL model;
%PseudoR2(NCov=7, CovFewer=CovReasL, CovMore=CovEduc);

* Close output;
PROC PRINTTO; RUN;
