* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';                                            
* Kill default titles on output; 
TITLE; 

***********************************************************************************;
*******       MACRO PROGRAMS TO AUTOMATE CALCULATIONS FOR EXAMPLE 4         *******;
*******               NOTHING IN HERE NEEDS TO BE CHANGED                   *******;
***********************************************************************************;

* To use FitTest macro;
* FitFewer = name of infocrit table for nested model;
* FitMore  = name of infocrit table for comparison model;
%MACRO FitTest(FitFewer=,FitMore=);
DATA &FitFewer.; LENGTH Name $30.; SET &FitFewer.; Name="&FitFewer."; RUN;
DATA &FitMore.;  LENGTH Name $30.; SET &FitMore.;  Name="&FitMore.";  RUN;
DATA FitCompare; LENGTH Name $30.; SET &FitFewer. &FitMore.; RUN;
DATA FitCompare; SET FitCompare; DevDiff=Lag1(Neg2LogLike)-Neg2LogLike;
     DFdiff=Parms-LAG1(Parms); Pvalue=1-PROBCHI(DevDiff,DFdiff);
     DROP AICC HQIC CAIC; RUN;
TITLE9 "Likelihood Ratio Test for &FitFewer. vs. &FitMore.";
PROC PRINT NOOBS DATA=FitCompare; RUN; TITLE9;
%MEND FitTest;

* To use PseudoR2 macro;
* Ncov =     TOTAL # entries in covariance parameters output table;
* CovFewer = name of covparms table for nested model;
* CovMore =  name of covparms table for comparison modell;
%MACRO PseudoR2(NCov=,CovFewer=,CovMore=);
DATA &CovFewer.; LENGTH Name $30.; SET &CovFewer.; Name="&CovFewer."; RUN;
DATA &CovMore.;  LENGTH Name $30.; SET &CovMore.;  Name="&CovMore.";  RUN;
DATA CovCompare; LENGTH Name $30.; SET &CovFewer. &CovMore.; RUN;
DATA CovCompare; SET CovCompare; 
     PseudoR2=(LAG&Ncov.(Estimate)-Estimate)/LAG&Ncov.(Estimate); RUN;
DATA CovCompare; SET CovCompare; 
     IF CovParm IN("UN(2,1)","UN(3,1)","UN(4,1)","UN(3,2)","UN(4,2)","UN(4,3)") 
     THEN DELETE; RUN;
TITLE9 "PsuedoR2 (% Reduction) for &CovFewer. vs. &CovMore.";
PROC PRINT NOOBS DATA=CovCompare; RUN; TITLE9;
%MEND PseudoR2;

********************************************************************************;
*******                      BEGIN EXAMPLE 4 MODELS                      *******;
********************************************************************************;

* Define global variable for file location -- CHANGE THIS TO YOUR DIRECTORY;
%LET example= C:\Dropbox\Workshop_Illinois_2018\Download\SAS;
LIBNAME example "&example.";

* Import data file from folder to work library;
* Add another version of predictors to be coded 0/1 for low/high;
DATA work.Example4; SET example.Example4; 
	IF freq=-.5 THEN freq01=0; IF freq=.5 THEN freq01=1;
	IF size=-.5 THEN size01=0; IF size=.5 THEN size01=1; RUN;
    
* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example4_SAS_Output.txt" 
             LOG=  "&example.\Example4_SAS_Output.txt"; RUN;

TITLE1 "Crosstabs for item types";
PROC FREQ DATA=work.Example4; TABLE freq01*size01; RUN; TITLE1;

*** Note: These models assume a stacked data structure in which each row
    provides the response time for a single subject and a single item;

TITLE1 "SAS Model 1: Empty Means Model: No Random Intercepts (E only)";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    CLASS Subject Item;
    MODEL rt = / SOLUTION DDFM=Satterthwaite; 
    ODS OUTPUT InfoCrit=FitEonly; * Save fit for comparison;
RUN; TITLE1;

TITLE1 "SAS Model 2: Add Level-2 Random Intercept for Subjects Model";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    CLASS Subject Item;
    MODEL rt = / SOLUTION DDFM=Satterthwaite;
    RANDOM INTERCEPT /SUBJECT=Subject TYPE=UN;  * Level 2 variance for subjects;
    ODS OUTPUT InfoCrit=FitRandSubjects; * Save fit for comparison;
RUN; TITLE1;
* Calculate difference in model fit relative to e-only model;
%FitTest(FitFewer=FitEonly, FitMore=FitRandSubjects);

TITLE1 "SAS Model 3: Add Level-2 Random Intercept for Items: Crossed Model";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    CLASS Subject Item;
    MODEL rt =  / SOLUTION DDFM=Satterthwaite;
    RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;    * Level 2 variance for items;
    RANDOM INTERCEPT / SUBJECT=Subject TYPE=UN; * Level 2 variance for subjects; 
    ODS OUTPUT InfoCrit=FitRandItems CovParms=CovEmpty; * Save fit, variances to compare;
RUN; TITLE1;
* Calculate difference in model fit relative to random subjects model;
%FitTest(FitFewer=FitRandSubjects, FitMore=FitRandItems);

TITLE1 "SAS Model 4: Random Subjects by Random Items Crossed Predictive Model";
TITLE2 "Using CLASS statement to get cell means and comparisons VIA LSMEANS";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    * Add freq and size to CLASS statement to use LSMEANS;
    CLASS Subject Item freq01 size01;
    * | operator estimates all possible main effects and interactions up to @ order;
    MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite OUTPM=ItemPred;
    RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;    * Level 2 variance for items;
    RANDOM INTERCEPT / SUBJECT=Subject TYPE=UN; * Level 2 variance for subjects; 
    ODS OUTPUT InfoCrit=FitRandItem CovParms=CovItemPred; * Save fit, variances to compare;
    * Requesting marginal means per condition (what Type 3 tests are for);
    LSMEANS freq01 size01; 
    * Requesting F-tests for simple main effects (more useful than marginal);
    LSMEANS freq01*size01 / SLICE=freq01 SLICE=size01;
RUN; TITLE1; TITLE2;
* Get total R2;
PROC CORR DATA=ItemPred; VAR pred rt; RUN;
* Calculate PseudoR2 relative to empty means model;
%PseudoR2(NCov=3, CovFewer=CovEmpty, CovMore=CovItemPred);

TITLE1 "SAS Model 5: Drop Random Item Intercept";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    CLASS Subject Item;
    MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite;
    RANDOM INTERCEPT / SUBJECT=Subject TYPE=UN; * Level 2 variance for subjects ONLY; 
    ODS OUTPUT InfoCrit=FitNoRandItem;          * Save fit to compare;
RUN; TITLE1;
* Calculate difference in model fit relative to random subjects and items predictive model;
%FitTest(FitFewer=FitNoRandItem, FitMore=FitRandItem);

TITLE1 "SAS Model 6: Add Random Slope for Effect of Freq over Subjects";
TITLE2 "Removed Freq and Size from CLASS to fit random slope";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    CLASS Subject Item;
    MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite;
    RANDOM INTERCEPT        / SUBJECT=Item TYPE=UN;     * Level 2 variance for items;
    RANDOM INTERCEPT freq01 / SUBJECT=Subject TYPE=UN;  * Level 2 variances for subjects; 
    ODS OUTPUT InfoCrit=FitRandFreq;                    * Save fit to compare;
RUN; TITLE1; TITLE2;
* Calculate difference in model fit relative to random subjects and items predictive model;
%FitTest(FitFewer=FitRandItem, FitMore=FitRandFreq);

TITLE1 "SAS Model 7: Add Random Slope for Effect of Size over Subjects";
PROC MIXED DATA=work.Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
    CLASS Subject Item;
    MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite;
    RANDOM INTERCEPT        / SUBJECT=Item TYPE=UN;     * Level 2 variance for items;
    RANDOM INTERCEPT size01 / SUBJECT=Subject TYPE=UN;  * Level 2 variances for subjects; 
    ODS OUTPUT InfoCrit=FitRandSize;                    * Save fit to compare;
RUN; TITLE1; 
* Calculate difference in model fit relative to random subjects and items predictive model;
%FitTest(FitFewer=FitRandItem, FitMore=FitRandSize);

* Close output;
PROC PRINTTO; RUN;
