* Encoding: UTF-8.
********************************************************************************.
*****                      EXAMPLE 1: BP AND WP MODELS                    ******.
********************************************************************************.

* Define file location -- CHANGE THIS TO YOUR DIRECTORY.
FILE HANDLE example /NAME = "C:\Dropbox\Workshop_Illinois_2018\Download\SPSS".

* SPSS code to open data and center predictors for analysis.
GET FILE = "example/Example1.sav".
DATASET NAME Example1 WINDOW=FRONT.
COMPUTE time1 = time - 1.
COMPUTE treat = group - 1.
VARIABLE LABELS  time1  "Time (0=pre-test 1=post-test)"
                 treat  "Treatment Group (0=control, 1=treatment)".  
EXECUTE.
DATASET ACTIVATE Example1 WINDOW=FRONT.

* Open output directory.
OUTPUT NAME Example1_SPSS_Output.

ECHO "Means by group and time for learning outcome".
SUMMARIZE
    /TABLES = outcome BY group BY time
    /FORMAT = NOLIST TOTAL 
    /CELLS = COUNT MEAN SEMEAN MIN MAX.

ECHO "SPSS Between-Person Empty Means Model via MIXED".
MIXED outcome BY PersonID time
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV R
     /FIXED  = 
     /REPEATED = time | SUBJECT(PersonID) COVTYPE(ID).

ECHO "SPSS Within-Person Empty Means Model via MIXED".
MIXED outcome BY PersonID time
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV R
     /FIXED  = 
     /REPEATED = time | SUBJECT(PersonID) COVTYPE(CS). 

ECHO "SPSS Between-Person Conditional Model via MIXED".
MIXED outcome BY PersonID time WITH time1 treat
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV R
     /FIXED  = time1 treat time1*treat
     /REPEATED = time | SUBJECT(PersonID) COVTYPE(ID)
     /TEST "Mean: Control Group at Pre-Test"     intercept 1 time1 0 treat 0 time1*treat 0
     /TEST "Mean: Control Group at Post-Test"    intercept 1 time1 1 treat 0 time1*treat 0
     /TEST "Mean: Treatment Group at Pre-Test"   intercept 1 time1 0 treat 1 time1*treat 0
     /TEST "Mean: Treatment Group at Post-Test"  intercept 1 time1 1 treat 1 time1*treat 1
     /TEST "Time Effect for Control Group"       time1 1 time1*treat 0
     /TEST "Time Effect for Treatment Group"     time1 1 time1*treat 1
     /TEST "Group Effect at Pre-Test"            treat 1 time1*treat 0
     /TEST "Group Effect at Post-Test"           treat 1 time1*treat 1.

ECHO "SPSS Within-Person Conditional Model via MIXED".
MIXED outcome BY PersonID time WITH time1 treat
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV R
     /FIXED  = time1 treat time1*treat
     /REPEATED = time | SUBJECT(PersonID) COVTYPE(CS)
     /TEST "Mean: Control Group at Pre-Test"     intercept 1 time1 0 treat 0 time1*treat 0
     /TEST "Mean: Control Group at Post-Test"    intercept 1 time1 1 treat 0 time1*treat 0
     /TEST "Mean: Treatment Group at Pre-Test"   intercept 1 time1 0 treat 1 time1*treat 0
     /TEST "Mean: Treatment Group at Post-Test"  intercept 1 time1 1 treat 1 time1*treat 1
     /TEST "Time Effect for Control Group"       time1 1 time1*treat 0
     /TEST "Time Effect for Treatment Group"     time1 1 time1*treat 1
     /TEST "Group Effect at Pre-Test"            treat 1 time1*treat 0
     /TEST "Group Effect at Post-Test"           treat 1 time1*treat 1.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS EXPORT=ALL LAYERS=PRINTSETTING MODELVIEWS=PRINTSETTING
  /DOC  DOCUMENTFILE="example\Example1_SPSS_Output.doc"
        NOTESCAPTIONS=YES WIDETABLES=SHRINK PAGEBREAKS=YES PAGESIZE=INCHES(8.5, 11.0) 
        TOPMARGIN=INCHES(0.5) BOTTOMMARGIN=INCHES(0.5) LEFTMARGIN=INCHES(0.5) RIGHTMARGIN=INCHES(0.5).
