* Encoding: UTF-8.

******************************************************************************.
******                    EXAMPLE 2 MODELS                              ******.
******************************************************************************.

* Define file location -- CHANGE THIS TO YOUR DIRECTORY.
FILE HANDLE example /NAME = "C:\Dropbox\Workshop_Illinois_2018\Download\SPSS".
* Open data and center predictors for analysis.
GET FILE = "example/Example23.sav".
DATASET NAME Example23 WINDOW=FRONT.
* Center time for polynomial models.
COMPUTE c1sess = session - 1.
VARIABLE LABELS c1sess "c1sess: Session Centered at 1". 
EXECUTE.
DATASET ACTIVATE Example23 WINDOW=FRONT.

* Open output directory.
OUTPUT NAME Example2_SPSS_Output.

ECHO "SPSS Model 0: Saturated Means, Unstructured Variances".
MIXED nm3rt BY ID session
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = session 
      /REPEATED = session | SUBJECT(ID) COVTYPE(UN)
      /EMMEANS  = TABLES(session).

ECHO "SPSS Model 1a: Empty Means, Random Intercept".
MIXED nm3rt BY ID session
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = 
      /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
      /REPEATED = session | SUBJECT(ID) COVTYPE(ID).

ECHO "SPSS Model 2a: Fixed Linear Time, Random Intercept".
MIXED nm3rt BY ID session WITH c1sess
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV G R
     /FIXED  = c1sess
     /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
     /REPEATED = session | SUBJECT(ID) COVTYPE(ID).

ECHO "SPSS Model 2b: Random Linear Time".
MIXED nm3rt BY ID session WITH c1sess
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV G R
     /FIXED  = c1sess
     /RANDOM = INTERCEPT c1sess | SUBJECT(ID) COVTYPE(UN)
     /REPEATED = session | SUBJECT(ID) COVTYPE(ID).

ECHO "SPSS Model 3a: Fixed Quadratic, Random Linear Time".
MIXED nm3rt BY ID session WITH c1sess
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV G R
     /FIXED  = c1sess c1sess*c1sess
     /RANDOM = INTERCEPT c1sess | SUBJECT(ID) COVTYPE(UN)
     /REPEATED = session | SUBJECT(ID) COVTYPE(ID)
     /SAVE = FIXPRED (predtime).
CORRELATIONS predtime nm3rt.

ECHO "SPSS Model 3b: Random Quadratic Time".
MIXED nm3rt BY ID session WITH c1sess
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = c1sess c1sess*c1sess
      /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
      /REPEATED = session | SUBJECT(ID) COVTYPE(ID)
      /TEST = "Intercept at Session 1" 	  intercept 1 c1sess 0   c1sess*c1sess 0
      /TEST = "Intercept at Session 2" 	  intercept 1 c1sess 1   c1sess*c1sess 1
      /TEST = "Intercept at Session 3" 	  intercept 1 c1sess 2   c1sess*c1sess 4
      /TEST = "Intercept at Session 4" 	  intercept 1 c1sess 3   c1sess*c1sess 9
      /TEST = "Intercept at Session 5" 	  intercept 1 c1sess 4   c1sess*c1sess 16
      /TEST = "Intercept at Session 6" 	  intercept 1 c1sess 5   c1sess*c1sess 25
      /TEST = "Linear Slope at Session 1" 	c1sess 1    c1sess*c1sess 0
      /TEST = "Linear Slope at Session 2" 	c1sess 1    c1sess*c1sess 2
      /TEST = "Linear Slope at Session 3" 	c1sess 1    c1sess*c1sess 4
      /TEST = "Linear Slope at Session 4" 	c1sess 1    c1sess*c1sess 6
      /TEST = "Linear Slope at Session 5" 	c1sess 1    c1sess*c1sess 8
      /TEST = "Linear Slope at Session 6" 	c1sess 1    c1sess*c1sess 10.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS EXPORT=ALL LAYERS=PRINTSETTING MODELVIEWS=PRINTSETTING
  /DOC  DOCUMENTFILE="example\Example2_SPSS_Output.doc"
        NOTESCAPTIONS=YES WIDETABLES=SHRINK PAGEBREAKS=YES PAGESIZE=INCHES(8.5, 11.0) 
        TOPMARGIN=INCHES(0.5) BOTTOMMARGIN=INCHES(0.5) LEFTMARGIN=INCHES(0.5) RIGHTMARGIN=INCHES(0.5).

******************************************************************************.
******                        EXAMPLE 3 MODELS                          ******.
******************************************************************************.

* Center level-2 predictor variables for analysis.
DATASET ACTIVATE Example23 WINDOW=FRONT.
COMPUTE age80  = age - 80.
COMPUTE reas22 = absreas - 22.
VARIABLE LABELS age80  "age80: Age Centered (0=80)"
                reas22 "reas22: Abstract Reasoning Centered (0=22)".
* Make education a grouping variable for purpose of demonstration only.
IF educyrs LE 12                   educgrp=1.
IF educyrs GT 12 AND educyrs LE 16 educgrp=2.
IF educyrs GT 16                   educgrp=3.
VARIABLE LABELS educgrp "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)".
* Remove cases with missing predictors. 
SELECT IF (NVALID(age80, reas22, educgrp)=3).
EXECUTE.

* Open output directory.
OUTPUT NAME Example3_SPSS_Output.

ECHO "SPSS Model 4a: Add Age as Predictor of Intercept, Linear, and Quadratic".
MIXED nm3rt BY ID session WITH c1sess age80
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
      /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
      /REPEATED = session | SUBJECT(ID) COVTYPE(ID)
      /TEST = "DF=3 Wald Test for Age Effects" age80 1; c1sess*age80 1; c1sess*c1sess*age80 1
      /SAVE = FIXPRED (predage)  
      /TEST = "Age Effect at Session 1" age80 1 c1sess*age80 0 c1sess*c1sess*age80 0
      /TEST = "Age Effect at Session 2" age80 1 c1sess*age80 1 c1sess*c1sess*age80 1
      /TEST = "Age Effect at Session 3" age80 1 c1sess*age80 2 c1sess*c1sess*age80 4
      /TEST = "Age Effect at Session 4" age80 1 c1sess*age80 3 c1sess*c1sess*age80 9
      /TEST = "Age Effect at Session 5" age80 1 c1sess*age80 4 c1sess*c1sess*age80 16
      /TEST = "Age Effect at Session 6" age80 1 c1sess*age80 5 c1sess*c1sess*age80 25.
CORRELATIONS predage nm3rt.

ECHO "SPSS Model 5a: Add Reasoning as Predictor of Intercept, Linear, and Quadratic".
MIXED nm3rt BY ID session WITH c1sess age80 reas22
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
                reas22 c1sess*reas22 c1sess*c1sess*reas22
      /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
      /REPEATED = session | SUBJECT(ID) COVTYPE(ID)
      /TEST = "DF=3 Wald Test for Reas Effects" reas22 1; c1sess*reas22 1; c1sess*c1sess*reas22 1
      /SAVE = FIXPRED (predreasQ).
CORRELATIONS predreasQ nm3rt. 

ECHO "SPSS Model 5b: Add Reasoning as Predictor of Intercept and Linear Only".
MIXED nm3rt BY ID session WITH c1sess age80 reas22
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 reas22 c1sess*reas22 
      /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
      /REPEATED = session | SUBJECT(ID) COVTYPE(ID)
      /TEST = "DF=2 Wald Test for Reas Effects" reas22 1; c1sess*reas22 1
      /TEST = "Reasoning Effect at Session 1" reas22 1 c1sess*reas22 0
      /TEST = "Reasoning Effect at Session 2" reas22 1 c1sess*reas22 1
      /TEST = "Reasoning Effect at Session 3" reas22 1 c1sess*reas22 2
      /TEST = "Reasoning Effect at Session 4" reas22 1 c1sess*reas22 3
      /TEST = "Reasoning Effect at Session 5" reas22 1 c1sess*reas22 4
      /TEST = "Reasoning Effect at Session 6" reas22 1 c1sess*reas22 5
      /SAVE = FIXPRED (predreasL).
CORRELATIONS predreasL nm3rt. 

ECHO "SPSS Model 6a: Add Education Group as Predictor of Intercept, Linear, and Quadratic".
MIXED nm3rt BY ID session educgrp WITH c1sess age80 reas22
      /METHOD = REML
      /PRINT  = SOLUTION TESTCOV G R
      /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 
                reas22 c1sess*reas22 educgrp c1sess*educgrp c1sess*c1sess*educgrp
      /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
      /REPEATED = session | SUBJECT(ID) COVTYPE(ID)
      /TEST = "DF=6 Wald Test for Educ Effects" educgrp -1 1 0; educgrp -1 0 1;  
                    c1sess*educgrp -1 1 0; c1sess*educgrp -1 0 1;
                    c1sess*c1sess*educgrp -1 1 0; c1sess*c1sess*educgrp -1 0 1 
      /EMMEANS = TABLES(educgrp) WITH (c1sess=0) COMPARE(educgrp)
      /EMMEANS = TABLES(educgrp) WITH (c1sess=5) COMPARE(educgrp)
      /TEST = "L vs. H Educ for for Main Effect" educgrp -1  0  1
      /TEST = "M vs. H Educ for for Main Effect" educgrp  0 -1  1
      /TEST = "L vs. M Educ for for Main Effect" educgrp -1  1  0
      /TEST = "L vs. H Educ for for Linear Session" c1sess*educgrp -1  0  1
      /TEST = "M vs. H Educ for for Linear Session" c1sess*educgrp  0 -1  1
      /TEST = "L vs. M Educ for for Linear Session" c1sess*educgrp -1  1  0
      /TEST = "L vs. H Educ for for Quadratic Session" c1sess*c1sess*educgrp -1  0  1
      /TEST = "M vs. H Educ for for Quadratic Session" c1sess*c1sess*educgrp  0 -1  1
      /TEST = "L vs. M Educ for for Quadratic Session" c1sess*c1sess*educgrp -1  1  0
      /SAVE = FIXPRED (prededuc).
CORRELATIONS prededuc nm3rt.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS EXPORT=ALL LAYERS=PRINTSETTING MODELVIEWS=PRINTSETTING
  /DOC  DOCUMENTFILE="example\Example3_SPSS_Output.doc"
        NOTESCAPTIONS=YES WIDETABLES=SHRINK PAGEBREAKS=YES PAGESIZE=INCHES(8.5, 11.0) 
        TOPMARGIN=INCHES(0.5) BOTTOMMARGIN=INCHES(0.5) LEFTMARGIN=INCHES(0.5) RIGHTMARGIN=INCHES(0.5).

