* Encoding: UTF-8.

***********************************************************************************.
*******                       BEGIN EXAMPLE 4 MODELS                        *******.
***********************************************************************************.

* Define file location -- CHANGE THIS TO YOUR DIRECTORY.
FILE HANDLE example /NAME = "C:\Dropbox\Workshop_Illinois_2018\Download\SPSS".

* Open file used in example -- CHANGE THIS.
GET FILE = "example/Example4.sav".
DATASET NAME Example4 WINDOW=FRONT.

* Adding another version of predictors to be coded 0/1 for low/high.
RECODE freq size (-.5=0) (.5=1) INTO freq01 size01.
EXECUTE.

* Open output directory.
OUTPUT NAME SPSS_Example4_Output.

ECHO "SPSS Model 1: Empty Means Model: No Random Intercepts (E only)".
MIXED rt BY Subject Item 
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV
     /FIXED  = .

ECHO "SPSS Model 2: Add Level-2 Random Intercept for Subjects Model".
MIXED rt BY Subject Item 
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV
     /FIXED  =
     /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN).

ECHO "SPSS Model 3: Add Level-2 Random Intercept for Items: Crossed Model".
MIXED rt BY Subject Item 
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV
     /FIXED  = 
     /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN)
     /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN).

ECHO "SPSS Model 4: Random Intercepts for Subjects and Items Crossed Predictive Model;".
ECHO "Using BY statement to get cell means and comparisons via EMMEANS".
MIXED rt BY Subject Item freq01 size01  
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV
     /FIXED  = freq01 size01 freq01*size01
     /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN)
     /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
     /EMMEANS = TABLES(freq01)
     /EMMEANS = TABLES(size01)
     /EMMEANS = TABLES(freq01*size01) COMPARE(freq01)
     /EMMEANS = TABLES(freq01*size01) COMPARE(size01).

ECHO "SPSS Model 5: Drop Random Item Intercept".
MIXED rt BY Subject Item freq01 size01  
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV
     /FIXED  = freq01 size01 freq01*size01
     /RANDOM = INTERCEPT | SUBJECT(Subject) COVTYPE(UN).

ECHO "SPSS Model 6: Add Random Slope for Effect of Freq over Subjects;".
ECHO "Removed Freq and Size from BY statement to fit random slope".
MIXED rt BY Subject Item WITH freq01 size01  
  /METHOD = REML
  /PRINT  = SOLUTION TESTCOV
  /FIXED  = freq01 size01 freq01*size01
  /RANDOM = INTERCEPT freq01 | SUBJECT(Subject) COVTYPE(UN)
  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN).

ECHO "SPSS Model 7: Add Random Slope for Effect of Size over Subjects;".
ECHO "Removed Freq and Size from BY statement to fit random slope".
MIXED rt BY Subject Item WITH freq01 size01  
     /METHOD = REML
     /PRINT  = SOLUTION TESTCOV
     /FIXED  = freq01 size01 freq01*size01
     /RANDOM = INTERCEPT size01 | SUBJECT(Subject) COVTYPE(UN)
     /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN).

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS EXPORT=ALL LAYERS=PRINTSETTING MODELVIEWS=PRINTSETTING
  /DOC  DOCUMENTFILE="example\Example4_SPSS_Output.doc"
        NOTESCAPTIONS=YES WIDETABLES=SHRINK PAGEBREAKS=YES PAGESIZE=INCHES(8.5, 11.0) 
        TOPMARGIN=INCHES(0.5) BOTTOMMARGIN=INCHES(0.5) LEFTMARGIN=INCHES(0.5) RIGHTMARGIN=INCHES(0.5).
