* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******                   EXAMPLE 1: BP AND WP MODELS                     ******
********************************************************************************

* Define global variable for file location - CHANGE THIS TO YOUR DIRECTORY
global example "C:\Dropbox\Workshop_Illinois_2018\Download\STATA"

* Open data file and center predictors for analysis
use "$example\Example1.dta", clear
gen time1 = time - 1
gen treat = group - 1
label variable time1 "Time (0=pre-test 1=post-test)"
label variable treat "Treatment Group (0=control, 1=treatment)"
 
* Save results to separate file
log using $example\Example1_STATA_Output.log, replace name(Example1) 
 
* Means by group and time for learning outcome
tabulate group time, summarize(outcome)
 
* STATA Between-Person Empty Means Model via mixed
mixed outcome ,  || PersonID:  , noconstant  /// 
    variance reml residuals(independent,t(time)) dfmethod(residual),
    estat wcorrelation, covariance      // R matrix
    estat wcorrelation,                 // RCORR matrix

* STATA Within-Person Empty Means Model via mixed
mixed outcome ,  || PersonID:  ,   /// 
    variance reml residuals(exchangeable,t(time)) dfmethod(satterthwaite),
    estat wcorrelation, covariance      // R matrix
    estat wcorrelation                  // RCORR matrix
    
* STATA Between-Person Conditional Model via mixed
mixed outcome c.time1 c.treat c.time1#c.treat, ///
    || PersonID:  , noconstant  /// 
    variance reml residuals(independent,t(time)) dfmethod(residual),
    estat wcorrelation, covariance      // R matrix
    estat wcorrelation,                 // RCORR matrix
    estat df, method(residual)          // print DDF for fixed effects
    * Request cell means
    margins, at(c.time1=(0 1) c.treat=(0 1)) vsquish
    * Request simple slopes, small = use DDF from above
    lincom 1*c.time  + 0*c.time#c.treat, small // time effect for control 
    lincom 1*c.time  + 1*c.time#c.treat, small // time effect for treat
    lincom 1*c.treat + 0*c.time#c.treat, small // group effect for pre-test
    lincom 1*c.treat + 1*c.time#c.treat, small // group effect for post-test

* STATA Within-Person Conditional Model via mixed
mixed outcome c.time1 c.treat c.time1#c.treat, ///
    || PersonID:  , noconstant  /// 
    variance reml residuals(exchangeable,t(time)) dfmethod(satterthwaite),
    estat wcorrelation, covariance      // R matrix
    estat wcorrelation                  // RCORR matrix
    estat df, method(satterthwaite)     // print DDF for fixed effects
    * Request cell means
    margins, at(c.time1=(0 1) c.treat=(0 1)) vsquish
    * Request simple slopes, small = use DDF from above
    lincom 1*c.time  + 0*c.time#c.treat, small // time effect for control 
    lincom 1*c.time  + 1*c.time#c.treat, small // time effect for treat
    lincom 1*c.treat + 0*c.time#c.treat, small // group effect for pre-test
    lincom 1*c.treat + 1*c.time#c.treat, small // group effect for post-test

* Close log
log close Example1
