* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******                      BEGIN EXAMPLE 2 MODELS                      *******
********************************************************************************

* Define global variable for file location -- CHANGE THIS TO YOUR DIRECTORY
global example "C:\Dropbox\Workshop_Illinois_2018\Download\STATA"
* Open file used in example -- CHANGE THIS
use "$example\Example23.dta", clear

* Center time for polynomial models (and make quadratic version)
gen c1sess = session - 1
label variable c1sess  "c1sess: Session Centered at 1"
gen c1sess2 = c1sess * c1sess
label variable c1sess2 "c1sess2: Quadratic Session Centered at 1"

* Save results to separate file
log using $example\Example2_STATA_Output.log, replace name(Example2) 
	
* STATA Model 0: Saturated Means, Unstructured Variances
mixed nm3rt ib(last).session, || id: , noconstant /// 
	   variance reml residuals(unstructured, t(session)) dfmethod(satterthwaite),
     estat ic, n(101)				      // AIC and BIC
     estat wcorrelation, covariance		  // R covariance matrix
     estat wcorrelation				      // R correlation matrix
     estat df, method(satterthwaite) 	  // print DDF for fixed effects
     contrast session, small			  // omnibus test of mean differences
     margins i.session				      // observed means per session
     marginsplot                          // plot observed means
	
* STATA Model 1a: Empty Means, Random Intercept
mixed nm3rt ,  || id:  ,  /// 
	    variance reml covariance(unstructured) residuals(independent,t(session)) ///
        dfmethod(satterthwaite),
      estat icc 		// get ICC
      estat ic, n(101)	// AIC and BIC 
	  estat recovariance, relevel(id),			// G matrix
	  estat df, method(satterthwaite),    		// print DDF for fixed effects
	
* STATA Model 2a: Fixed Linear Time, Random Intercept
mixed nm3rt c.c1sess,  || id:  ,  /// 
	    variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101)				    // AIC and BIC
      estat recovariance, relevel(id)	// G matrix
      estat df, method(satterthwaite) 	// print DDF for fixed effects
      estimates store FixLin            // store for LRT

* STATA Model 2b: Random Linear Time
mixed nm3rt c.c1sess,  || id: c1sess,  /// 
	  variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101)					            // AIC and BIC
      estat recovariance, relevel(id)			    // G matrix
      estat recovariance, relevel(id) correlation	// GCORR matrix
      estat df, method(satterthwaite)			    // print DDF for fixed effects
      estimates store RandLin                       // store for LRT
      lrtest RandLin FixLin                         // print LRT

* STATA Model 3a: Fixed Quadratic, Random Linear Time
mixed nm3rt c.c1sess c.c1sess#c.c1sess,  || id: c1sess,  /// 
	  variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101) 					            // AIC and BIC
      estat recovariance, relevel(id)			    // G matrix
      estat recovariance, relevel(id) correlation	// GCORR matrix
      estat df, method(satterthwaite) 			    // print DDF for fixed effects
      estimates store FixQuad                       // store for LRT
      predict predtime		// save fixed-effect predicted outcomes
corr predtime nm3rt			// get total r to make r2

* STATA Model 3b: Random Quadratic Time
mixed nm3rt c.c1sess c.c1sess#c.c1sess,  || id: c1sess c1sess2,  /// 
	    variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101) 					            // AIC and BIC
      estat recovariance, relevel(id)			    // G matrix
      estat recovariance, relevel(id) correlation	// GCORR matrix
      estat df, method(satterthwaite), 	            // print DDF for fixed effects
      estimates store RandQuad                      // store for LRT  
      lrtest RandQuad FixQuad                       // do LRT
      margins, at(c.c1sess=(0(1)5)) vsquish		    // intercepts per session
      marginsplot, name(predicted_means, replace)	// plot intercepts
      margins, at(c.c1sess=(0(1)5)) dydx(c.c1sess) vsquish // linear slope per session
      marginsplot                                   // plot quadratic effect

 * Close log	
 log close Example2
 
 ******************************************************************************
 ****** 						EXAMPLE 3 MODELS						 ******
 ******************************************************************************
  
* Center level-2 predictor variables for analysis
gen age80 = age - 80
gen reas22 = absreas - 22
label variable age80 "age80: Age Centered (0=80 years)"
label variable reas22 "reas22: Abstract Reasoning Centered (0=22)"
* Make education a grouping variable for purpose of demonstration only
gen educgrp=.   
replace educgrp=1 if (educyrs <= 12) 
replace educgrp=2 if (educyrs > 12 & educyrs <= 16)
replace educgrp=3 if (educyrs > 16)
label variable educgrp "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)"
* Create new variable to hold number of missing cases
* Then drop cases with incomplete predictors
egen nummiss = rowmiss(age80 reas22 educgrp)
drop if nummiss>0

* Save results to separate file
log using $example\Example3_STATA_Output.log, replace name(Example3) 

* STATA Model 4a: Add Age as Predictor of Intercept, Linear, and Quadratic
mixed nm3rt c.c1sess c.c1sess#c.c1sess   		              ///
	     c.age80 c.c1sess#c.age80 c.c1sess#c.c1sess#c.age80,  ///
	     || id: c1sess c1sess2,				                  ///
	     variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101), 					        // AIC and BIC
      estat recovariance, relevel(id),			    // G matrix
      estat recovariance, relevel(id) correlation,	// GCORR matrix
      estat df, method(satterthwaite),    		    // print DDF for fixed effects
      test (c.age80=0) (c.c1sess#c.age80=0) (c.c1sess#c.c1sess#c.age80=0) // DF=3 Wald test	
      predict predage			                    // save fixed-effect predicted outcomes
      margins, at(c.c1sess=(0(1)5)) dydx(c.age80) vsquish     // age slope per session
      margins, at(c.c1sess=(0(1)5) c.age80=(-5 0 5)) vsquish  // predictions per session
      marginsplot                                             // plot age predictions
corr predage nm3rt		                                      // get total r to make r2

* STATA Model 5a: Add Reasoning as Predictor of Intercept, Linear, and Quadratic
mixed nm3rt c.c1sess c.c1sess#c.c1sess   			              ///
	     c.age80 c.c1sess#c.age80 c.c1sess#c.c1sess#c.age80       ///
	     c.reas22 c.c1sess# c.reas22 c.c1sess#c.c1sess#c.reas22,  ///
	     || id: c1sess c1sess2, 					              /// 
	   variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101), 					        // AIC and BIC
      estat recovariance, relevel(id),			    // G matrix
      estat recovariance, relevel(id) correlation,	// GCORR matrix
      estat df, method(satterthwaite),              // print DDF for fixed effects
      test (c.reas22=0) (c.c1sess#c.reas22=0) (c.c1sess#c.c1sess#c.reas22=0) // DF=3 Wald test
      predict predreasQ		 	                    // save fixed-effect predicted outcomes 
corr predreasQ nm3rt			                    // get total r to make r2

* STATA Model 5b: Add Reasoning as Predictor of Intercept and Linear Only
mixed nm3rt c.c1sess c.c1sess#c.c1sess   			              ///
         c.age80 c.c1sess#c.age80 c.c1sess#c.c1sess#c.age80       ///
         c.reas22 c.c1sess# c.reas22, || id: c1sess c1sess2,      /// 
         variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
      estat ic, n(101) 					             // AIC and BIC
      estat recovariance, relevel(id)		     	 // G matrix
      estat recovariance, relevel(id) correlation	 // GCORR matrix
      estat df, method(satterthwaite)                // print DDF for fixed effects
      test (c.reas22=0) (c.c1sess#c.reas22=0)        // DF=2 Wald test
      margins, at(c.c1sess=(0(1)5)) dydx(c.reas22) vsquish     // reas slope per session
      margins, at(c.c1sess=(0(1)5) c.reas22=(-5 0 5)) vsquish  // predictions per session
      marginsplot 	                                           // plot reas predictions
      predict predreasL		  	        // save fixed-effect predicted outcomes 
corr predreasL nm3rt			    	// get total r to make r2

* STATA Model 6a: Add Education Group as Predictor of Intercept, Linear, and Quadratic
mixed nm3rt c.c1sess c.c1sess#c.c1sess c.age80 c.c1sess#c.age80       ///
         c.c1sess#c.c1sess#c.age80 c.reas22 c.c1sess#c.reas22         ///
         ib(last).educgrp c.c1sess#ib(last).educgrp		              /// 
         c.c1sess#c.c1sess#ib(last).educgrp, || id: c1sess c1sess2,   /// 
         variance reml covariance(un) residuals(independent,t(session)) dfmethod(satterthwaite),  
	estat ic, n(101) 					            // AIC and BIC
	estat recovariance, relevel(id)  			    // G matrix
	estat recovariance, relevel(id) correlation	    // GCORR matrix
	estat df, method(satterthwaite)       		    // print DDF for fixed effects
	contrast i.educgrp, small				        // omnibus group diff on intercept
	contrast c.c1sess#i.educgrp,	small			// omnibus group diff on linear
	contrast c.c1sess#c.c1sess#i.educgrp, small	    // omnibus group diff on quadratic
* Estimating group means at first and last sessions
 	margins ib(last).educgrp,  at(c.c1sess=(0 5))  	
* Contrasts between groups on intercept, linear, and quadratic slopes
 	test 1.educgrp=3.educgrp, small				        // Low vs. High: Intercept
	test 2.educgrp=3.educgrp, small 		     	    // Med vs. High: Intercept
	test 1.educgrp=2.educgrp, small				        // Low vs. Med:  Intercept
	test 1.educgrp#c.c1sess=3.educgrp#c.c1sess, small	// Low vs. High: Linear
	test 2.educgrp#c.c1sess=3.educgrp#c.c1sess, small	// Med vs. High: Linear
	test 1.educgrp#c.c1sess=2.educgrp#c.c1sess, small	// Low vs. Med:  Linear
	test 1.educgrp#c.c1sess#c.c1sess=3.educgrp#c.c1sess#c.c1sess, small  // Low vs. High: Quad
	test 2.educgrp#c.c1sess#c.c1sess=3.educgrp#c.c1sess#c.c1sess, small  // Med vs. High: Quad
	test 1.educgrp#c.c1sess#c.c1sess=2.educgrp#c.c1sess#c.c1sess, small  // Low vs. Med:  Quad
	margins, at(c.c1sess=(0(1)5) educgrp=(1 2 3)) vsquish  // predictions per session
	marginsplot                                            // plot educ predictions
	predict prededuc			       // save fixed-effect predicted outcomes 
corr prededuc nm3rt			           // get total r to make r2

* Close log	
log close Example3

