* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******                      BEGIN EXAMPLE 4 MODELS                      *******
********************************************************************************

* Define global variable for file location -- CHANGE THIS TO YOUR DIRECTORY
global example "C:\Dropbox\Workshop_Illinois_2018\Download\STATA"
 
* Open data file and add another version of predictors coded 0/1 for low/high
use "$example\Example4.dta", clear
gen freq01 = freq
gen size01 = size
recode freq01 (-.5=0)
recode freq01 ( .5=1)
recode size01 (-.5=0)
recode size01 ( .5=1)
 
* Save results to separate file
log using $example\Example4_STATA_Output.log, replace name(Example4)

* STATA Model 1: Empty Means Model: No Random Intercepts (E only)
mixed rt , variance reml, 
    estimates store Eonly   // save for LRT

* STATA Model 2: Add Random Intercept for Subjects Model
mixed rt ,  || subject: , variance reml,
    estimates store RandSubjects,   // save for LRT
    lrtest RandSubjects Eonly       // test random subjects
    
* STATA Model 3: Add Random Intercept for Items: Crossed Model
mixed rt , || _all: R.subject, ||_all: R.item, variance reml,
    estimates store RandItems       // save for LRT
    lrtest RandItems RandSubjects   // test random items
    
* STATA Model 4: Random Intercepts for Subjects and Items Crossed Predictive Model
mixed rt ib(last).freq01 ib(last).size01 i.freq01#i.size01, ///
    || _all: R.subject, ||_all: R.item, variance reml dfmethod(satterthwaite),
    estimates store NewRandItem            // save for LRT
    estat df, method(satterthwaite)        // print DDF for fixed effects
    margins i.freq01 i.size01              // marginal means
    contrast i.freq01 i.size01, small      // marginal mean diff tests
    margins i.freq01#i.size01              // cell means
    pwcompare i.freq01#i.size01, small pv  // cell mean diff tests

* STATA Model 5: Drop Random Item Intercept
mixed rt ib(last).freq01 ib(last).size01 i.freq01#i.size01, ///
    || subject: ,  variance reml dfmethod(satterthwaite),
    estimates store NoRandItem             // save for LRT
    lrtest NewRandItem NoRandItem          // test random items
    margins i.freq01 i.size01              // marginal means
    contrast i.freq01 i.size01, small      // marginal mean diff tests
    margins i.freq01#i.size01              // cell means
    pwcompare i.freq01#i.size01, small pv  // cell mean diff tests

* This code should have worked (I think), but it didn't converge
 
* STATA Model 6: Add Random Slope for Effect of Freq over Subjects
* Removed Freq and Size from i. statement to fit random slope

* mixed rt c.freq01 c.size01 c.freq01#c.size01, ///
*   || subject: freq01, covariance(unstructured), ///
*   || _all: R.item , variance reml dfmethod(satterthwaite),
*   estimates store RandFreq       // save for LRT
*   lrtest RandFreq NewRandItem    // Test random freq

 * Close log    
 log close Example4

